==> ginkgocadx_2.4.1.1.orig.tar.gz: ginkgocadx-2.4.1.1/src/cadxcore/main/gui/dicombrowsercomponent.h <==
/*
*  
*  $Id: dicombrowsercomponent.h 3648 2011-04-04 11:56:18Z tovar $
*  Ginkgo CADx Project
*
*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*
*/
#pragma once
#include "dicombrowsercomponentbase.h"
#include <string>
#include <vector>
#include <api/imodelodicom.h>
#include <set>

namespace GNC {
	namespace GUI {
		class DicomBrowserComponent: public DicomBrowserComponentBase
		{
		public:
			DicomBrowserComponent(wxWindow *parent,
            wxWindowID winid = wxID_ANY,
            const wxPoint& pos = wxDefaultPosition,
            const wxSize& size = wxDefaultSize,
            long style = wxTAB_TRAVERSAL | wxNO_BORDER);
			~DicomBrowserComponent();

			void SetModel(IModeloDicom& modelo);
			void SetDiagnosticModel(IModeloDicom& modelo);

			void OnDicomDirIzqAddAll(wxCommandEvent& );
			void OnDicomDirDerDelAll(wxCommandEvent& );

			void OnTreeIzqItemActivated(wxTreeEvent& );

			void OnTreeDerItemActivated(wxTreeEvent& );

			void OnAdd(wxCommandEvent& );

			void OnDel(wxCommandEvent&);

			void OnTreeIzqBeginDrag(wxTreeEvent& );

			void OnTreeDerBeginDrag(wxTreeEvent& );

			void AddItemsSeleccionados();

			void AddItemsSeleccionados(wxArrayTreeItemIds& idsSeleccionados);

			void DelItemsSeleccionados();
			void DelItemsSeleccionados(wxArrayTreeItemIds& idsSeleccionados);

			void OnTreeDerItemMenu(wxTreeEvent& event);

			void OnTreeIzqItemMenu(wxTreeEvent& event);

			wxTreeItemId HelperBuscaID(const wxTreeItemId& padre, const wxString& uid);

			void HelperCopiaEnProfundidad(const wxTreeItemId& padreDer, const wxTreeItemId& padreIzq);

			void HelperGetAllPatients(wxTreeListCtrl* pTree, wxArrayTreeItemIds& idsSeleccionados);

			void HelperRellenaPathsDicomDir(const wxTreeItemId& id, std::set<std::string>& listaPaths);
			void HelperRellenaUIDs(const wxTreeItemId& id, std::set<std::string>& seriesSet, bool isDiagnostic);

			std::list<std::string> GetSelectedPaths();
			std::list<std::string> GetSelectedUIDs(bool isDiagnostic);

		protected:
			wxImageList* m_pImageList;
		};
	}
}

==> ginkgocadx_2.6.0.0~rc.orig.tar.gz: ginkgocadx-2.6.0.0/src/cadxcore/main/gui/dicombrowsercomponent.h <==
/*
*  
*  $Id: dicombrowsercomponent.h 3834 2011-05-10 07:42:57Z carlos $
*  Ginkgo CADx Project
*
*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*
*/
#pragma once
#include "dicombrowsercomponentbase.h"
#include <string>
#include <vector>
#include <api/dicom/imodelodicom.h>
#include <set>

namespace GNC {
	namespace GUI {
		class DicomBrowserComponent: public DicomBrowserComponentBase
		{
		public:
			DicomBrowserComponent(wxWindow *parent,
            wxWindowID winid = wxID_ANY,
            const wxPoint& pos = wxDefaultPosition,
            const wxSize& size = wxDefaultSize,
            long style = wxTAB_TRAVERSAL | wxNO_BORDER);
			~DicomBrowserComponent();

			void SetModel(IModeloDicom& modelo);
			void SetDiagnosticModel(IModeloDicom& modelo);

			void OnDicomDirIzqAddAll(wxCommandEvent& );
			void OnDicomDirDerDelAll(wxCommandEvent& );

			void OnTreeIzqItemActivated(wxTreeEvent& );

			void OnTreeDerItemActivated(wxTreeEvent& );

			void OnAdd(wxCommandEvent& );

			void OnDel(wxCommandEvent&);

			void OnTreeIzqBeginDrag(wxTreeEvent& );

			void OnTreeDerBeginDrag(wxTreeEvent& );

			void AddItemsSeleccionados();

			void AddItemsSeleccionados(wxArrayTreeItemIds& idsSeleccionados);

			void DelItemsSeleccionados();
			void DelItemsSeleccionados(wxArrayTreeItemIds& idsSeleccionados);

			void OnTreeDerItemMenu(wxTreeEvent& event);

			void OnTreeIzqItemMenu(wxTreeEvent& event);

			wxTreeItemId HelperBuscaID(const wxTreeItemId& padre, const wxString& uid);

			void HelperCopiaEnProfundidad(const wxTreeItemId& padreDer, const wxTreeItemId& padreIzq);

			void HelperGetAllPatients(wxTreeListCtrl* pTree, wxArrayTreeItemIds& idsSeleccionados);

			void HelperRellenaPathsDicomDir(const wxTreeItemId& id, std::set<std::string>& listaPaths);
			void HelperRellenaUIDs(const wxTreeItemId& id, std::set<std::string>& seriesSet, bool isDiagnostic);

			std::list<std::string> GetSelectedPaths();
			std::list<std::string> GetSelectedUIDs(bool isDiagnostic);

		protected:
			wxImageList* m_pImageList;
		};
	}
}
